==> nocc-1.8.1.tbz: www/nocc/lang/it.php <==
<?php
/**
 * Language configuration file for NOCC
 *
 * Copyright 2001 Nicolas Chalanset <nicocha@free.fr>
 * Copyright 2001 Olivier Cahagne <cahagn_o@epita.fr>
 *
 * This file is part of NOCC. NOCC is free software under the terms of the
 * GNU General Public License. You should have received a copy of the license
 * along with NOCC.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    NOCC
 * @subpackage Translations
 * @license    http://www.gnu.org/licenses/ GNU General Public License
 * @version    SVN: $Id: it.php 1931 2009-07-05 11:07:47Z gerundt $
 */

/** Italian (Italiano)
 *
 * See the qqq 'language' for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Francesco Andreozzi <ozzo@lauratiamo.it>
 * @author Gianfranco
 * @author Guido Venturini <guido@technojuice.com>
 */

$lang_locale = 'it_IT.UTF-8';
$default_date_format = '%A %d %B %Y';
$no_locale_date_format = '%d-%m-%Y';
$default_time_format = '%H:%M';
$err_user_empty = 'Campo di login vuoto';
$err_passwd_empty = 'Non hai digitato la password';
$alt_delete = 'Elimina il messaggio selezionato';
$alt_delete_one = 'Elimina il messaggio';
$alt_new_msg = 'Nuovo messaggio';
$alt_reply = 'Rispondi al Mittente';
$alt_reply_all = 'Rispondi a tutti';
$alt_forward = 'Inoltra';
$title_next_page = 'Pagina successiva';
$title_prev_page = 'Pagina precedente';
$title_next_msg = 'Prossimo';
$title_prev_msg = 'Precedente';
$html_on = 'sicuro';
$html_theme_label = 'Tema';
$html_welcome = 'Benvenuto in %1$s';
$html_login = 'Utente';
$html_passwd = 'Password';
$html_submit = 'Ok';
$html_help = 'Aiuto';
$html_wrong = 'Login o password non corretti';
$html_retry = 'Riprova';
$html_remember = 'Ricorda Impostazioni';
$html_msgperpage_label = 'Messaggi per pagina';
$html_preferences = 'Preferenze';
$html_full_name_label = 'Nome';
$html_email_address_label = 'Indirizzo E-mail';
$html_ccself = 'auto Cc proprio indizzo';
$html_hide_addresses = 'Nascondi indirizzo';
$html_outlook_quoting = 'Quote Outlook-style';
$html_reply_to = 'Rispondi a';
$html_use_signature = 'Usa la firma';
$html_signature = 'Firma';
$html_reply_leadin_label = 'Prefisso per risposte';
$html_prefs_updated = 'Preferenze aggiornate';
$html_manage_folders_link = 'Configura Cartelle IMAP';
$html_manage_filters_link = 'Configura Filtri Email';
$html_use_graphical_smilies = 'Usa smilies grafici';
$html_sent_folder_label = 'Copia email inviate in cartella predefinita';
$html_trash_folder_label = 'Sposta i messaggi cancellati in una cartella dedicata';
$html_send_html_mail = 'Invia messaggi in formato HTML';
$html_folders = 'Cartelle';
$html_folders_create_failed = 'La cartella non può essere creata!';
$html_folders_sub_failed = 'Impossibile connettersi alla cartella!';
$html_folders_unsub_failed = 'Impossibile disconnettersi dalla cartella!';
$html_folders_rename_failed = 'La cartella non può essere rinominata!';
$html_folders_updated = 'Cartelle aggiornate';
$html_folder_subscribe = 'Connettiti a';
$html_folder_rename = 'Rinomina';
$html_folder_create = 'Crea una nuova cartella con nome';
$html_folder_remove = 'Disconnettiti da';
$html_folder_delete = 'Elimina';
$html_folder_to = 'a';
$html_filter_remove = 'Cancella';
$html_filter_body = 'Corpo del messaggio';
$html_filter_subject = 'Soggetto';
$html_filter_to = 'Campo To';
$html_filter_cc = 'Campo Cc';
$html_filter_from = 'Campo From';
$html_filter_change_tip = 'Sovrascrivere direttamente un filtro per cambiarlo.';
$html_reapply_filters = 'Riapplica tutti i filtri';
$html_filter_contains = 'contiene';
$html_filter_name = 'Nome filtro';
$html_filter_action = 'Azione filtro';
$html_filter_moveto = 'Sposta in';
$html_select_one = '--Seleziona Uno--';
$html_and = 'e';
$html_new_msg_in = 'Nuovo messaggio in';
$html_or = 'o';
$html_move = 'Sposta';
$html_copy = 'Copia';
$html_messages_to = 'Messaggi selezionati in';
$html_gotopage = 'Vai alla Pagina';
$html_gotofolder = 'Vai alla Cartella';
$html_other_folders = 'Lista Cartelle';
$html_page = 'Pagina';
$html_of = 'di';
$html_view_header = 'Mostra intestazione';
$html_remove_header = 'Nascondi intestazione';
$html_inbox = 'Posta in Arrivo';
$html_new_msg = 'Scrivi';
$html_reply = 'Rispondi';
$html_reply_all = 'Rispondi a tutti';
$html_forward = 'Inoltra';
$html_forward_info = 'Il messaggio inoltrato sara` inviato come allegato a questo messaggio';
$html_delete = 'Elimina';
$html_new = 'Nuovo';
$html_mark = 'Elimina';
$html_att_label = 'Allegato';
$html_atts_label = 'Allegati';
$html_att_unknown = '[sconosciuto]';
$html_attach = 'Allega';
$html_attach_forget = 'Devi allegare il file prima di inviare il messaggio !';
$html_attach_delete = 'Elimina i files selezionati';
$html_attach_none = 'Devi selezionare un file da allegare!';
$html_sort_by = 'Ordina per';
$html_sort = 'Ordina';
$html_from = 'da';
$html_subject = 'Oggetto';
$html_date = 'Data';
$html_sent = 'Invia';
$html_wrote = 'scritto';
$html_size = 'Dimensione';
$html_totalsize = 'Dimensione Totale';
$html_to = 'A';
$html_nosubject = 'Senza Oggetto';
$html_send = 'Invia';
$html_cancel = 'Annulla';
$html_no_mail = 'Non vi sono nuovi messaggi.';
$html_logout = 'Esci';
$html_msg = 'Messaggio';
$html_msgs = 'Messaggi';
$html_configuration = 'Questo server non è configurato correttamente!';
$html_priority_label = 'Priorita';
$html_lowest = 'Più bassa';
$html_low = 'Bassa';
$html_normal = 'Normale';
$html_high = 'Alta';
$html_highest = 'Più alta';
$html_receipt = 'Richiedi conferma di recapito';
$html_select = 'Seleziona';
$html_select_all = 'Inverti Selezione';
$html_loading_image = 'Apertura immagine';
$html_send_confirmed = 'La tua e-mail è stata accettata per la consegna';
$html_no_sendaction = 'Nessuna azione specificata. Prova ad abilitare i JavaScript.';
$html_error_occurred = 'Si è verificato un errore';
$html_prefs_file_error = 'Impossibile aprire per la modifica il file delle preferenze.';
$html_wrap = 'Nuovo testo a capo alla colonna:';
$html_usenet_separator = 'Separatore ("-- \n") prima della firma';
$html_mark_as = 'Contrassegna come';
$html_read = 'letto';
$html_unread = 'non letto';
$html_encoding_label = 'Encoding caratteri';
$html_add = 'Nuovo';
$html_contacts = '%1$s Contatti';
$html_modify = 'Modifica';
$html_back = 'Indietro';
$html_contact_add = 'Aggiungi nuovo contatto';
$html_contact_mod = 'Modifica un contatto';
$html_contact_first = 'Nome';
$html_contact_last = 'Cognome';
$html_contact_nick = 'Nick';
$html_contact_mail = 'Mail';
$html_contact_list = 'Lista dei Contatti di %1$s';
$html_contact_del = 'dalla lista dei contatti';
$html_contact_err1 = 'Il numero massimo dei contatti è';
$html_contact_err2 = 'Non puoi aggiungere altri contatti';
$html_contact_err3 = 'Non hai i privilegi necessari per accedere alla lista contatti';
$html_del_msg = 'Eliminare i messaggi selezionati ?';
$original_msg = '-- Messaggio Originale --';
$to_empty = 'Il campo \'A\' non può essere vuoto !';
$html_images_display = 'Mostra immagini';
$html_smtp_error_no_conn = 'Impossibile stabilire una connessione SMTP';
$html_smtp_error_unexpected = 'Risposta inattesa dal server SMTP:';
$lang_could_not_connect = 'Non è possibile connettersi al server';
$lang_invalid_msg_num = 'Numero messaggio errato';
$html_file_upload_attack = 'Possibile attacco tramite caricamento di files esterni';
$html_invalid_email_address = 'Indirizzo e-mail non valido';
$html_invalid_msg_per_page = 'Numero di messaggi per pagina non valido';
$html_invalid_wrap_msg = 'Ampiezza testo a capo non valida';
$html_seperate_msg_win = 'Messaggi in finestre separate';
$html_err_file_contacts = 'Impossibile aprire in scrittura il file dei contatti.';
$html_session_file_error = 'Impossibile aprire in scrittura il file di sessione';
$html_search = 'Cerca';

==> nocc-1.8.3.tbz: www/nocc/lang/it.php <==
<?php
/**
 * Language configuration file for NOCC
 *
 * Copyright 2001 Nicolas Chalanset <nicocha@free.fr>
 * Copyright 2001 Olivier Cahagne <cahagn_o@epita.fr>
 *
 * This file is part of NOCC. NOCC is free software under the terms of the
 * GNU General Public License. You should have received a copy of the license
 * along with NOCC.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    NOCC
 * @subpackage Translations
 * @license    http://www.gnu.org/licenses/ GNU General Public License
 * @version    SVN: $Id: it.php 2164 2010-04-05 12:50:59Z gerundt $
 */

/** Italian (Italiano)
 *
 * See the qqq 'language' for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Darth Kule
 * @author Francesco Andreozzi <ozzo@lauratiamo.it>
 * @author Gianfranco
 * @author Guido Venturini <guido@technojuice.com>
 */

$lang_locale = 'it_IT.UTF-8';
$default_date_format = '%A %d %B %Y';
$no_locale_date_format = '%d-%m-%Y';
$default_time_format = '%H:%M';
$err_user_empty = 'Campo di login vuoto';
$err_passwd_empty = 'Non hai digitato la password';
$alt_delete = 'Elimina il messaggio selezionato';
$alt_delete_one = 'Elimina il messaggio';
$alt_new_msg = 'Nuovo messaggio';
$alt_reply = 'Rispondi al Mittente';
$alt_reply_all = 'Rispondi a tutti';
$alt_forward = 'Inoltra';
$title_next_page = 'Pagina successiva';
$title_prev_page = 'Pagina precedente';
$title_next_msg = 'Prossimo';
$title_prev_msg = 'Precedente';
$html_theme_label = 'Tema';
$html_welcome = 'Benvenuto in %1$s';
$html_login = 'Utente';
$html_submit = 'Ok';
$html_help = 'Aiuto';
$html_wrong = 'Login o password non corretti';
$html_retry = 'Riprova';
$html_remember = 'Ricorda Impostazioni';
$html_msgperpage_label = 'Messaggi per pagina';
$html_preferences = 'Preferenze';
$html_full_name_label = 'Nome';
$html_email_address_label = 'Indirizzo E-mail';
$html_ccself = 'auto Cc proprio indizzo';
$html_hide_addresses = 'Nascondi indirizzo';
$html_outlook_quoting = 'Quote Outlook-style';
$html_reply_to = 'Rispondi a';
$html_use_signature = 'Usa la firma';
$html_signature = 'Firma';
$html_reply_leadin_label = 'Prefisso per risposte';
$html_prefs_updated = 'Preferenze aggiornate';
$html_manage_folders_link = 'Configura Cartelle IMAP';
$html_manage_filters_link = 'Configura Filtri Email';
$html_use_graphical_smilies = 'Usa smilies grafici';
$html_sent_folder_label = 'Copia email inviate in cartella predefinita';
$html_trash_folder_label = 'Sposta i messaggi cancellati in una cartella dedicata';
$html_send_html_mail = 'Invia messaggi in formato HTML';
$html_folders = 'Cartelle';
$html_folders_create_failed = 'La cartella non può essere creata!';
$html_folders_sub_failed = 'Impossibile connettersi alla cartella!';
$html_folders_unsub_failed = 'Impossibile disconnettersi dalla cartella!';
$html_folders_rename_failed = 'La cartella non può essere rinominata!';
$html_folders_updated = 'Cartelle aggiornate';
$html_folder_subscribe = 'Connettiti a';
$html_folder_rename = 'Rinomina';
$html_folder_create = 'Crea una nuova cartella con nome';
$html_folder_remove = 'Disconnettiti da';
$html_folder_delete = 'Elimina';
$html_folder_to = 'a';
$html_filter_remove = 'Cancella';
$html_filter_body = 'Corpo del messaggio';
$html_filter_subject = 'Soggetto';
$html_filter_to = 'Campo To';
$html_filter_cc = 'Campo Cc';
$html_filter_from = 'Campo From';
$html_filter_change_tip = 'Sovrascrivere direttamente un filtro per cambiarlo.';
$html_reapply_filters = 'Riapplica tutti i filtri';
$html_filter_contains = 'contiene';
$html_filter_name = 'Nome filtro';
$html_filter_action = 'Azione filtro';
$html_filter_moveto = 'Sposta in';
$html_select_one = '--Seleziona Uno--';
$html_and = 'e';
$html_new_msg_in = 'Nuovo messaggio in';
$html_or = 'o';
$html_move = 'Sposta';
$html_copy = 'Copia';
$html_messages_to = 'Messaggi selezionati in';
$html_gotopage = 'Vai alla Pagina';
$html_gotofolder = 'Vai alla Cartella';
$html_other_folders = 'Lista Cartelle';
$html_page = 'Pagina';
$html_of = 'di';
$html_view_header = 'Mostra intestazione';
$html_remove_header = 'Nascondi intestazione';
$html_inbox = 'Posta in Arrivo';
$html_new_msg = 'Scrivi';
$html_reply = 'Rispondi';
$html_reply_all = 'Rispondi a tutti';
$html_forward = 'Inoltra';
$html_forward_info = 'Il messaggio inoltrato sara` inviato come allegato a questo messaggio';
$html_delete = 'Elimina';
$html_new = 'Nuovo';
$html_mark = 'Elimina';
$html_att_label = 'Allegato';
$html_unknown = '[sconosciuto]';
$html_attach = 'Allega';
$html_attach_forget = 'Devi allegare il file prima di inviare il messaggio !';
$html_attach_delete = 'Elimina i files selezionati';
$html_attach_none = 'Devi selezionare un file da allegare!';
$html_sort_by = 'Ordina per';
$html_sort = 'Ordina';
$html_from = 'da';
$html_subject = 'Oggetto';
$html_date = 'Data';
$html_sent_label = 'Invia';
$html_wrote = 'scritto';
$html_size = 'Dimensione';
$html_totalsize = 'Dimensione Totale';
$html_to = 'A';
$html_nosubject = 'Senza Oggetto';
$html_send = 'Invia';
$html_cancel = 'Annulla';
$html_no_mail = 'Non vi sono nuovi messaggi.';
$html_logout = 'Esci';
$html_msg = 'Messaggio';
$html_msgs = 'Messaggi';
$html_configuration = 'Questo server non è configurato correttamente!';
$html_priority_label = 'Priorita';
$html_lowest = 'Più bassa';
$html_low = 'Bassa';
$html_normal = 'Normale';
$html_high = 'Alta';
$html_highest = 'Più alta';
$html_receipt = 'Richiedi conferma di recapito';
$html_select = 'Seleziona';
$html_select_all = 'Inverti Selezione';
$html_loading_image = 'Apertura immagine';
$html_send_confirmed = 'La tua e-mail è stata accettata per la consegna';
$html_no_sendaction = 'Nessuna azione specificata. Prova ad abilitare i JavaScript.';
$html_error_occurred = 'Si è verificato un errore';
$html_prefs_file_error = 'Impossibile aprire per la modifica il file delle preferenze.';
$html_wrap = 'Nuovo testo a capo alla colonna:';
$html_usenet_separator = 'Separatore ("-- \n") prima della firma';
$html_mark_as = 'Contrassegna come';
$html_read = 'letto';
$html_unread = 'non letto';
$html_encoding_label = 'Encoding caratteri';
$html_add = 'Nuovo';
$html_contacts = '%1$s Contatti';
$html_modify = 'Modifica';
$html_back = 'Indietro';
$html_contact_add = 'Aggiungi nuovo contatto';
$html_contact_mod = 'Modifica un contatto';
$html_contact_first = 'Nome';
$html_contact_last = 'Cognome';
$html_contact_nick = 'Nick';
$html_contact_mail = 'Mail';
$html_contact_list = 'Lista dei Contatti di %1$s';
$html_contact_del = 'dalla lista dei contatti';
$html_contact_err1 = 'Il numero massimo dei contatti è';
$html_contact_err2 = 'Non puoi aggiungere altri contatti';
$html_contact_err3 = 'Non hai i privilegi necessari per accedere alla lista contatti';
$html_del_msg = 'Eliminare i messaggi selezionati ?';
$original_msg = '-- Messaggio Originale --';
$to_empty = 'Il campo \'A\' non può essere vuoto !';
$html_images_display = 'Mostra immagini';
$html_smtp_error_no_conn = 'Impossibile stabilire una connessione SMTP';
$html_smtp_error_unexpected = 'Risposta inattesa dal server SMTP:';
$lang_could_not_connect = 'Non è possibile connettersi al server';
$lang_invalid_msg_num = 'Numero messaggio errato';
$html_file_upload_attack = 'Possibile attacco tramite caricamento di files esterni';
$html_invalid_email_address = 'Indirizzo e-mail non valido';
$html_invalid_msg_per_page = 'Numero di messaggi per pagina non valido';
$html_invalid_wrap_msg = 'Ampiezza testo a capo non valida';
$html_seperate_msg_win = 'Messaggi in finestre separate';
$html_err_file_contacts = 'Impossibile aprire in scrittura il file dei contatti.';
$html_session_file_error = 'Impossibile aprire in scrittura il file di sessione';
$html_search = 'Ricerca';
